html

Macro html 

html!() { /* proc-macro */ }
Parses an HTML node tree and expands to an expression that builds the element tree and renders it via render_tree(), yielding the resulting Html collection of nodes.