html_str!() { /* proc-macro */ }Expand description
Parses an HTML node tree and expands to an expression that builds the
element tree and immediately renders it to an HTML String via html().
html_str!() { /* proc-macro */ }Parses an HTML node tree and expands to an expression that builds the
element tree and immediately renders it to an HTML String via html().