tree!() { /* proc-macro */ }Expand description
Parses an HTML node tree and expands to the constructed element object tree without rendering it, allowing the resulting structure to be inspected or rendered later.
tree!() { /* proc-macro */ }Parses an HTML node tree and expands to the constructed element object tree without rendering it, allowing the resulting structure to be inspected or rendered later.