ElementDefaults

Trait ElementDefaults 

pub trait ElementDefaults {
    // Required methods
    fn _get_attributes(&self) -> String;
    fn _get_children(&self) -> String;

    // Provided methods
    fn get_attributes(&self) -> String { ... }
    fn get_children(&self) -> String { ... }
}
Provides default access to the rendered attribute and child markup of an element, used by generated renderable implementations.

Required Methods

fn _get_attributes(&self) -> String

Returns the serialized attribute string for this element.

fn _get_children(&self) -> String

Returns the serialized inner HTML of this element’s children.

Provided Methods

fn get_attributes(&self) -> String

Returns the element’s attributes as an HTML attribute string.

fn get_children(&self) -> String

Returns the element’s children rendered as an HTML string.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors