The Html container holding rendered roots, hooks and retained renderables.
Re-exports
pub use crate::utils::ElementResult;pub use crate::utils::document;
Structs
- Element
- The
Elementclass. - Html
- The result of rendering an HTML template: the live DOM root elements, the
map of
@name-tagged hook elements, and the retained Rust renderables that keep elements and callbacks alive for the lifetime of this structure.
Type Aliases
- Hooks
- Map of
@name-tagged element bindings keyed by their declared name.