Module render

Module render 

The Render trait and its implementations for rendering values to DOM/HTML.

Structs

Arc
A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.

Traits

Render
Implemented by values that can be rendered both to an HTML string and to live DOM nodes, optionally exposing @name hooks and retained renderables.
Write
A trait for writing or formatting into Unicode-accepting buffers or streams.

Type Aliases

Renderables
A collection of retained renderables kept alive for the lifetime of an Html.
Result
The type returned by formatter methods.